/*
 * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { SGraphyItem } from "@saga-web/graphy/lib";
import { SColor, SLine, SPainter, SPoint } from "@saga-web/draw/lib";

/**
 * 吸附时高亮对象
 *
 * @author  郝建龙
 */
export class HighlightItem extends SGraphyItem {
    /** 对象与鼠标位置距离   */
    distance: number = 0;
    /** 对象类型   */
    private type: number = 1;

    /** 点对象数据   */
    _point: SPoint = new SPoint();
    get point(): SPoint {
        return this._point;
    } // Get point
    set point(v: SPoint) {
        this._point = v;
        this.type = 1;
    } // Set point

    /** 点对象数据   */
    _line: SLine = new SLine();
    get line(): SLine {
        return this._line;
    } // Get line
    set line(v: SLine) {
        this._line = v;
        this.type = 2;
    } // Set line

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      对象
     * @param distance  对象与鼠标位置的距离
     */
    constructor(
        parent: SGraphyItem | null,
        data: SPoint | SLine,
        distance: number
    ) {
        super(parent);
        if (data instanceof SPoint) {
            this.point = data;
        } else {
            this.line = data;
        }
        this.distance = distance;
        this.visible = false;
        this.zOrder = 19;
    } // Constructor

    /**
     * Item绘制操作
     *
     * @param   painter       painter对象
     */
    onDraw(painter: SPainter): void {
        painter.pen.lineWidth = painter.toPx(5);
        painter.pen.color = new SColor("#409EFF");
        if (this.type == 1) {
            painter.drawCircle(this.point.x, this.point.y, painter.toPx(10));
        } else if (this.type == 2) {
            painter.pen.lineWidth = painter.toPx(10);
            painter.drawLine(this.line);
        }
    } // Function onDraw()
} // Class HighlightItem
